const {
  freebies: Freebies,
  freebiesImage: FreebiesImage,
  user: User,
} = require("../models");

class FreebiesController {
  static async getAllFreebies(req, res, next) {
    try {
      let payload;
      if (req.query.status !== "all" && req.query.status) {
        payload = {
          where: { status: req.query.status },
        };
      }
      const data = await Freebies.findAll(payload);
      res.status(200).json(data);
    } catch (error) {
      next(error);
    }
  }
  static async getFreebiesByUser(req, res, next) {
    try {
      const { id } = req.user;
      const data = await Freebies.findAll({
        where: { userId: +id },
        include: [{ model: FreebiesImage, key: "id" }],
      });
      console.log();
      res.status(200).json(data);
    } catch (error) {
      next(error);
    }
  }

  static async updateFreebiesStatus(req, res, next) {
    try {
      const { id } = req.params;
      const { status } = req.body;
      const freebies = await Freebies.findByPk(id);
      if (!freebies) throw { name: "freebies_not_found" };
      await Freebies.update({ status }, { where: { id } });
      res.status(200).json({ message: "Status freebies berhasil di update" });
    } catch (error) {
      next(error);
    }
  }

  static async createFreebies(req, res, next) {
    try {
      const { id } = req.user;
      const { title, description, linkDownload } = req.body;
      const { thumbnail, highlights, donate } = req.files;

      console.log(req.files);
      console.log(req.body);

      const pictName = Math.floor(Math.random() * 10000 * 999).toString();

      const data = await Freebies.create({
        title,
        description,
        linkDownload,
        donate: pictName,
        userId: id,
        thumbnail: pictName,
      });

      if (!/^image/.test(thumbnail.mimetype)) return res.sendStatus(400);
      thumbnail.mv(
        process.cwd() + "/upload/freebies/thumbnail/" + pictName + ".jpg"
      );
      if (!/^image/.test(thumbnail.mimetype)) return res.sendStatus(400);
      donate.mv(process.cwd() + "/upload/freebies/donate/" + pictName + ".jpg");

      for (let i = 0; i < highlights.length; i++) {
        const highlightname = Math.floor(
          Math.random() * 10000 * 999
        ).toString();

        await FreebiesImage.create({
          freebiesId: data.id,
          image: highlightname,
        });

        if (!/^image/.test(highlights[i].mimetype)) return res.sendStatus(400);
        highlights[i].mv(
          process.cwd() + "/upload/freebies/highlight/" + highlightname + ".jpg"
        );
      }
      res.status(201).json({ message: "success" });
    } catch (error) {
      next(error);
    }
  }

  static async removeFreebies(req, res, next) {
    try {
      const { id } = req.params;
      const freebies = await Freebies.findByPk(id);
      if (!freebies) throw { name: "freebies_not_found" };
      await Freebies.destroy({ where: { id } });
      res.status(200).json({ message: "Berhasil delete" });
    } catch (error) {
      next(error);
    }
  }

  static async getOneFreebies(req, res, next) {
    try {
      const { id } = req.params;
      const freebies = await Freebies.findByPk(id, {
        include: [{ model: FreebiesImage }, { model: User }],
      });
      if (!freebies) throw { name: "freebies_not_found" };
      //   console.log(freebies);
      res.status(200).json(freebies);
    } catch (error) {
      next(error);
    }
  }
}

module.exports = FreebiesController;
