const { topic: Topic, module: Module, course: Course } = require("../models");
class TopicController {
  static async getTopicByModule(req, res, next) {
    try {
      const { id } = req.params;
      const topic = await Topic.findAll({
        where: { moduleId: id },
        include: [{ model: Module, key: "id" }],
      });
      if (!topic) throw { name: "topic_not_found" };
      res.status(200).json(topic);
    } catch (error) {
      next(error);
    }
  }

  static async getOneTopic(req, res, next) {
    try {
      const { id } = req.params;
      const topic = await Topic.findByPk(id, {
        include: [
          { model: Module, key: "id" },
          { model: Course, key: "courseId" },
        ],
      });
      if (!topic) throw { name: "topic_not_found" };
      res.status(200).json(topic);
    } catch (error) {
      next(error);
    }
  }

  static async getTopicByCourse(req, res, next) {
    try {
      const { id } = req.params;
      const topic = await Topic.findAll({ where: { courseId: id } });
      if (!topic) throw { name: "topic_not_found" };
      res.status(200).json(topic);
    } catch (error) {
      next(error);
    }
  }

  static async createTopic(req, res, next) {
    try {
      const { title, video, duration, description, moduleId, courseId } =
        req.body;
      await Topic.create({
        title,
        video,
        duration,
        description,
        moduleId,
        courseId,
      });
      res.status(201).json({ message: "Topic has been created" });
    } catch (error) {
      next(error);
    }
  }

  static async removeTopic(req, res, next) {
    try {
      const { id } = req.params;
      const topic = await Topic.findByPk(id);
      if (!topic) throw { name: "topic_not_found" };
      await Topic.destroy({ where: { id } });
      res.status(200).json({ message: "Topic has been deleted" });
    } catch (error) {
      next(error);
    }
  }

  static async updateTopic(req, res, next) {
    try {
      const { id } = req.params;
      const { description, title, video, duration, moduleId } = req.body;

      const topic = await Topic.findByPk(id);
      if (!topic) throw { name: "topic_not_found" };
      await Topic.update(
        { description, title, video, duration, moduleId },
        {
          where: {
            id,
          },
        }
      );
      res
        .status(200)
        .json({ message: `Topic ${topic.title} has been updated` });
    } catch (error) {
      next(error);
    }
  }
}
module.exports = TopicController;
